{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "Apply base quality score recalibration",
            "requirements": [
                {
                    "dockerPull": "broadinstitute/gatk:4.1.7.0",
                    "class": "DockerRequirement"
                }
            ],
            "hints": [
                {
                    "ramMin": 5000,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_001876"
                            ],
                            "version": [
                                "4.1.7"
                            ],
                            "package": "GATK"
                        }
                    ],
                    "class": "SoftwareRequirement"
                },
                {
                    "outputDirType": "keep_output_dir",
                    "keep_cache": 1024,
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "label": "Indexed sorted BAM with labeled duplicates",
                    "secondaryFiles": [
                        {
                            "pattern": ".bai",
                            "required": null
                        }
                    ],
                    "id": "#gatk-applyBSQR-with-interval.cwl/bam"
                },
                {
                    "type": "File",
                    "label": "Scatter intervals file",
                    "id": "#gatk-applyBSQR-with-interval.cwl/intervallist"
                },
                {
                    "type": "File",
                    "label": "Recalibration table",
                    "id": "#gatk-applyBSQR-with-interval.cwl/recaltable"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "label": "Reference genome",
                    "secondaryFiles": [
                        {
                            "pattern": ".amb",
                            "required": null
                        },
                        {
                            "pattern": ".ann",
                            "required": null
                        },
                        {
                            "pattern": ".bwt",
                            "required": null
                        },
                        {
                            "pattern": ".pac",
                            "required": null
                        },
                        {
                            "pattern": ".sa",
                            "required": null
                        },
                        {
                            "pattern": ".fai",
                            "required": null
                        },
                        {
                            "pattern": "^.dict",
                            "required": null
                        }
                    ],
                    "id": "#gatk-applyBSQR-with-interval.cwl/reference"
                },
                {
                    "type": "string",
                    "label": "Sample Name",
                    "id": "#gatk-applyBSQR-with-interval.cwl/sample"
                }
            ],
            "baseCommand": "/gatk/gatk",
            "arguments": [
                "--java-options",
                "-Xmx4G",
                "ApplyBQSR",
                {
                    "prefix": "-R",
                    "valueFrom": "$(inputs.reference)"
                },
                {
                    "prefix": "-I",
                    "valueFrom": "$(inputs.bam)"
                },
                {
                    "prefix": "--bqsr-recal-file",
                    "valueFrom": "$(inputs.recaltable)"
                },
                {
                    "prefix": "-L",
                    "valueFrom": "$(inputs.intervallist)"
                },
                {
                    "prefix": "-O",
                    "valueFrom": "$(inputs.sample)nodups_BQSR.bam"
                }
            ],
            "id": "#gatk-applyBSQR-with-interval.cwl",
            "https://schema.org/codeRepository": "https://github.com/arvados/arvados-tutorial",
            "https://schema.org/license": "https://www.gnu.org/licenses/agpl-3.0.en.html",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "label": "Recalibrated BAM for given interval",
                    "secondaryFiles": [
                        {
                            "pattern": "^.bai",
                            "required": null
                        }
                    ],
                    "outputBinding": {
                        "glob": "*nodups_BQSR.bam"
                    },
                    "id": "#gatk-applyBSQR-with-interval.cwl/recalbam"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Generate recalibration table for BQSR",
            "requirements": [
                {
                    "dockerPull": "broadinstitute/gatk:4.1.7.0",
                    "class": "DockerRequirement"
                }
            ],
            "hints": [
                {
                    "ramMin": 5000,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_001876"
                            ],
                            "version": [
                                "4.1.7"
                            ],
                            "package": "GATK"
                        }
                    ],
                    "class": "SoftwareRequirement"
                },
                {
                    "outputDirType": "keep_output_dir",
                    "keep_cache": 1024,
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "label": "Indexed sorted BAM with labeled duplicates",
                    "secondaryFiles": [
                        {
                            "pattern": ".bai",
                            "required": null
                        }
                    ],
                    "id": "#gatk-baserecalibrator-with-interval.cwl/bam"
                },
                {
                    "type": "File",
                    "label": "Scatter intervals file",
                    "id": "#gatk-baserecalibrator-with-interval.cwl/intervallist"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "label": "VCF of known SNPS sites for BQSR",
                    "secondaryFiles": [
                        {
                            "pattern": ".idx",
                            "required": null
                        }
                    ],
                    "id": "#gatk-baserecalibrator-with-interval.cwl/knownsites1"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "label": "VCF of known indel sites for BQSR",
                    "secondaryFiles": [
                        {
                            "pattern": ".tbi",
                            "required": null
                        }
                    ],
                    "id": "#gatk-baserecalibrator-with-interval.cwl/knownsites2"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "label": "Reference genome",
                    "secondaryFiles": [
                        {
                            "pattern": ".amb",
                            "required": null
                        },
                        {
                            "pattern": ".ann",
                            "required": null
                        },
                        {
                            "pattern": ".bwt",
                            "required": null
                        },
                        {
                            "pattern": ".pac",
                            "required": null
                        },
                        {
                            "pattern": ".sa",
                            "required": null
                        },
                        {
                            "pattern": ".fai",
                            "required": null
                        },
                        {
                            "pattern": "^.dict",
                            "required": null
                        }
                    ],
                    "id": "#gatk-baserecalibrator-with-interval.cwl/reference"
                },
                {
                    "type": "string",
                    "label": "Sample Name",
                    "id": "#gatk-baserecalibrator-with-interval.cwl/sample"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "label": "Recalibration table for given interval",
                    "outputBinding": {
                        "glob": "*.table"
                    },
                    "id": "#gatk-baserecalibrator-with-interval.cwl/recaltable"
                }
            ],
            "baseCommand": "/gatk/gatk",
            "arguments": [
                "--java-options",
                "-Xmx4G",
                "BaseRecalibrator",
                {
                    "prefix": "-R",
                    "valueFrom": "$(inputs.reference)"
                },
                {
                    "prefix": "-I",
                    "valueFrom": "$(inputs.bam)"
                },
                {
                    "prefix": "--known-sites",
                    "valueFrom": "$(inputs.knownsites1)"
                },
                {
                    "prefix": "--known-sites",
                    "valueFrom": "$(inputs.knownsites2)"
                },
                {
                    "prefix": "-L",
                    "valueFrom": "$(inputs.intervallist)"
                },
                {
                    "prefix": "-O",
                    "valueFrom": "$(inputs.sample)_recal_data.table"
                }
            ],
            "id": "#gatk-baserecalibrator-with-interval.cwl",
            "https://schema.org/codeRepository": "https://github.com/arvados/arvados-tutorial",
            "https://schema.org/license": "https://www.gnu.org/licenses/agpl-3.0.en.html"
        },
        {
            "class": "CommandLineTool",
            "label": "Call variants with GATK HaplotypeCaller",
            "requirements": [
                {
                    "dockerPull": "broadinstitute/gatk:4.1.7.0",
                    "class": "DockerRequirement"
                }
            ],
            "hints": [
                {
                    "ramMin": 3500,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_001876"
                            ],
                            "version": [
                                "4.1.7"
                            ],
                            "package": "GATK"
                        }
                    ],
                    "class": "SoftwareRequirement"
                },
                {
                    "outputDirType": "keep_output_dir",
                    "keep_cache": 1024,
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "label": "Recalibrated BAM for given interval",
                    "secondaryFiles": [
                        {
                            "pattern": "^.bai",
                            "required": null
                        }
                    ],
                    "id": "#gatk-haplotypecaller-with-interval.cwl/bam"
                },
                {
                    "type": "File",
                    "label": "Scatter intervals file",
                    "id": "#gatk-haplotypecaller-with-interval.cwl/intervallist"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "label": "Reference genome",
                    "secondaryFiles": [
                        {
                            "pattern": ".amb",
                            "required": null
                        },
                        {
                            "pattern": ".ann",
                            "required": null
                        },
                        {
                            "pattern": ".bwt",
                            "required": null
                        },
                        {
                            "pattern": ".pac",
                            "required": null
                        },
                        {
                            "pattern": ".sa",
                            "required": null
                        },
                        {
                            "pattern": ".fai",
                            "required": null
                        },
                        {
                            "pattern": "^.dict",
                            "required": null
                        }
                    ],
                    "id": "#gatk-haplotypecaller-with-interval.cwl/reference"
                },
                {
                    "type": "string",
                    "label": "Sample Name",
                    "id": "#gatk-haplotypecaller-with-interval.cwl/sample"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "label": "GVCF for given interval",
                    "secondaryFiles": [
                        {
                            "pattern": ".tbi",
                            "required": null
                        }
                    ],
                    "outputBinding": {
                        "glob": "*vcf.gz"
                    },
                    "id": "#gatk-haplotypecaller-with-interval.cwl/gvcf"
                }
            ],
            "baseCommand": "/gatk/gatk",
            "arguments": [
                "--java-options",
                "-Xmx4G",
                "HaplotypeCaller",
                {
                    "prefix": "-R",
                    "valueFrom": "$(inputs.reference)"
                },
                {
                    "prefix": "-I",
                    "valueFrom": "$(inputs.bam)"
                },
                {
                    "prefix": "-L",
                    "valueFrom": "$(inputs.intervallist)"
                },
                {
                    "prefix": "-O",
                    "valueFrom": "$(inputs.sample)-$(inputs.intervallist.nameroot).gatk.g.vcf.gz"
                },
                {
                    "prefix": "-ERC",
                    "valueFrom": "GVCF"
                },
                {
                    "prefix": "-GQB",
                    "valueFrom": "5"
                },
                {
                    "prefix": "-GQB",
                    "valueFrom": "20"
                },
                {
                    "prefix": "-GQB",
                    "valueFrom": "60"
                }
            ],
            "id": "#gatk-haplotypecaller-with-interval.cwl",
            "https://schema.org/codeRepository": "https://github.com/arvados/arvados-tutorial",
            "https://schema.org/license": "https://www.gnu.org/licenses/agpl-3.0.en.html"
        },
        {
            "class": "CommandLineTool",
            "label": "Filter unused alternates",
            "requirements": [
                {
                    "dockerPull": "broadinstitute/gatk:4.1.7.0",
                    "class": "DockerRequirement"
                }
            ],
            "hints": [
                {
                    "ramMin": 5000,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_001876"
                            ],
                            "version": [
                                "4.1.7"
                            ],
                            "package": "GATK"
                        }
                    ],
                    "class": "SoftwareRequirement"
                },
                {
                    "outputDirType": "keep_output_dir",
                    "keep_cache": 1024,
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "label": "GVCF for given interval",
                    "secondaryFiles": [
                        {
                            "pattern": ".tbi",
                            "required": null
                        }
                    ],
                    "id": "#gatk-selectvariants.cwl/gvcf"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "label": "Reference genome",
                    "secondaryFiles": [
                        {
                            "pattern": ".amb",
                            "required": null
                        },
                        {
                            "pattern": ".ann",
                            "required": null
                        },
                        {
                            "pattern": ".bwt",
                            "required": null
                        },
                        {
                            "pattern": ".pac",
                            "required": null
                        },
                        {
                            "pattern": ".sa",
                            "required": null
                        },
                        {
                            "pattern": ".fai",
                            "required": null
                        },
                        {
                            "pattern": "^.dict",
                            "required": null
                        }
                    ],
                    "id": "#gatk-selectvariants.cwl/reference"
                },
                {
                    "type": "string",
                    "label": "Sample Name",
                    "id": "#gatk-selectvariants.cwl/sample"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "label": "Given interval filtered GVCF",
                    "outputBinding": {
                        "glob": "*g.vcf.gz"
                    },
                    "id": "#gatk-selectvariants.cwl/filteredgvcf"
                }
            ],
            "baseCommand": "/gatk/gatk",
            "arguments": [
                "--java-options",
                "-Xmx4G",
                "SelectVariants",
                {
                    "prefix": "-R",
                    "valueFrom": "$(inputs.reference)"
                },
                {
                    "prefix": "--remove-unused-alternates",
                    "valueFrom": "true"
                },
                {
                    "prefix": "-V",
                    "valueFrom": "$(inputs.gvcf.path)"
                },
                {
                    "prefix": "-O",
                    "valueFrom": "selected$(inputs.gvcf.basename)"
                }
            ],
            "id": "#gatk-selectvariants.cwl",
            "https://schema.org/codeRepository": "https://github.com/arvados/arvados-tutorial",
            "https://schema.org/license": "https://www.gnu.org/licenses/agpl-3.0.en.html"
        },
        {
            "class": "Workflow",
            "label": "Variant calling workflow for given interval",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "label": "Indexed sorted BAM with labeled duplicates",
                    "secondaryFiles": [
                        {
                            "pattern": ".bai",
                            "required": null
                        }
                    ],
                    "id": "#main/bam"
                },
                {
                    "type": "File",
                    "label": "Scatter intervals file",
                    "id": "#main/intervallist"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "label": "VCF of known SNPS sites for BQSR",
                    "secondaryFiles": [
                        {
                            "pattern": ".idx",
                            "required": null
                        }
                    ],
                    "id": "#main/knownsites1"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "label": "VCF of known indel sites for BQSR",
                    "secondaryFiles": [
                        {
                            "pattern": ".tbi",
                            "required": null
                        }
                    ],
                    "id": "#main/knownsites2"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "label": "Reference genome",
                    "secondaryFiles": [
                        {
                            "pattern": ".amb",
                            "required": null
                        },
                        {
                            "pattern": ".ann",
                            "required": null
                        },
                        {
                            "pattern": ".bwt",
                            "required": null
                        },
                        {
                            "pattern": ".pac",
                            "required": null
                        },
                        {
                            "pattern": ".sa",
                            "required": null
                        },
                        {
                            "pattern": ".fai",
                            "required": null
                        },
                        {
                            "pattern": "^.dict",
                            "required": null
                        }
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": "string",
                    "label": "Sample Name",
                    "id": "#main/sample"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "label": "Given interval filtered GVCF",
                    "outputSource": "#main/selectvariants/filteredgvcf",
                    "id": "#main/gvcf"
                }
            ],
            "steps": [
                {
                    "run": "#gatk-applyBSQR-with-interval.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/applyBQSR/bam"
                        },
                        {
                            "source": "#main/intervallist",
                            "id": "#main/applyBQSR/intervallist"
                        },
                        {
                            "source": "#main/basecalibrator/recaltable",
                            "id": "#main/applyBQSR/recaltable"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/applyBQSR/reference"
                        },
                        {
                            "source": "#main/sample",
                            "id": "#main/applyBQSR/sample"
                        }
                    ],
                    "out": [
                        "#main/applyBQSR/recalbam"
                    ],
                    "id": "#main/applyBQSR"
                },
                {
                    "run": "#gatk-baserecalibrator-with-interval.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/basecalibrator/bam"
                        },
                        {
                            "source": "#main/intervallist",
                            "id": "#main/basecalibrator/intervallist"
                        },
                        {
                            "source": "#main/knownsites1",
                            "id": "#main/basecalibrator/knownsites1"
                        },
                        {
                            "source": "#main/knownsites2",
                            "id": "#main/basecalibrator/knownsites2"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/basecalibrator/reference"
                        },
                        {
                            "source": "#main/sample",
                            "id": "#main/basecalibrator/sample"
                        }
                    ],
                    "out": [
                        "#main/basecalibrator/recaltable"
                    ],
                    "id": "#main/basecalibrator"
                },
                {
                    "run": "#gatk-haplotypecaller-with-interval.cwl",
                    "in": [
                        {
                            "source": "#main/applyBQSR/recalbam",
                            "id": "#main/haplotypecaller/bam"
                        },
                        {
                            "source": "#main/intervallist",
                            "id": "#main/haplotypecaller/intervallist"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/haplotypecaller/reference"
                        },
                        {
                            "source": "#main/sample",
                            "id": "#main/haplotypecaller/sample"
                        }
                    ],
                    "out": [
                        "#main/haplotypecaller/gvcf"
                    ],
                    "id": "#main/haplotypecaller"
                },
                {
                    "run": "#gatk-selectvariants.cwl",
                    "in": [
                        {
                            "source": "#main/haplotypecaller/gvcf",
                            "id": "#main/selectvariants/gvcf"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/selectvariants/reference"
                        },
                        {
                            "source": "#main/sample",
                            "id": "#main/selectvariants/sample"
                        }
                    ],
                    "out": [
                        "#main/selectvariants/filteredgvcf"
                    ],
                    "id": "#main/selectvariants"
                }
            ],
            "id": "#main",
            "https://schema.org/codeRepository": "https://github.com/arvados/arvados-tutorial",
            "https://schema.org/license": "https://www.gnu.org/licenses/agpl-3.0.en.html"
        }
    ],
    "cwlVersion": "v1.1",
    "$namespaces": {
        "s": "https://schema.org/",
        "edam": "http://edamontology.org/"
    }
}
